@@ -76,12 +76,20 @@ class Manager(object):
                             vec = h.Vector()
                             varRef = '_ref_' + var
                             if time_interval_recording is None:
-                                vec.record(point_process, 
-                                           getattr(sec(0.5), varRef))
+                                if point_process is not None:
+                                    vec.record(point_process, 
+                                               getattr(sec(0.5), varRef))
+                                else:
+                                    vec.record(getattr(sec(0.5), varRef))
                             else:
-                                vec.record(point_process,
-                                           getattr(sec(0.5), varRef), 
-                                           time_interval_recording)
+                                if point_process is not None:
+                                    vec.record(point_process,
+                                               getattr(sec(0.5), varRef), 
+                                               time_interval_recording)
+                                else:
+                                    vec.record(getattr(sec(0.5), varRef), 
+                                               time_interval_recording)
+                                    
                             vecRef.vecs[var] = vec
                             alreadyPresent = True
                             success = True
@@ -250,7 +258,7 @@ class Manager(object):
                        return ref.vecs[var]
     def get_time(self):
         """Return the vector time associated with the voltage"""
-        return self.manager.groups['t']
+        return self.groups['t']
     
     def sum_vector(self, vec1, vec2):
         """Sums two vectors with the same length. The vector are 
